/*
 * Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */

/*
 * This file is part of the FSG PAPI Project
 *
 * The FSG PAPI Project is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FSG PAPI Project is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the FSG PAPI Project; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/* $Id: printer.c,v 1.1.1.1 2002/09/18 19:30:13 jacobs Exp $ */
#pragma ident	"@(#)printer.c	1.1	02/08/22 SMI"

/*LINTLIBRARY*/

#include <stdlib.h>
#include <papi_impl.h>

#ifdef HAVE_GETTTEXT
#include <libintl.h>
#else /* don't HAVE_GETTEXT */
#define gettext(x)	(x)
#endif /* HAVE_GETTEXT */

void
papiPrinterFree(papi_printer_t printer)
{
	printer_t *tmp = printer;

	if (tmp != NULL) {
		papiAttributeListFree(tmp->attributes);
		free(tmp);
	}
}

void
papiPrinterListFree(papi_printer_t *printers)
{
	if (printers != NULL) {
		int i;

		for (i = 0 ; printers[i] != NULL ; i++)
			free(printers[i]);
		free(printers);
	}
}

papi_status_t
papiPrintersList(papi_service_t handle, const char **requested_attrs,
		const papi_filter_t *filter, papi_printer_t **printers)
{
	service_t *svc = handle;

	if ((svc == NULL) || (printers == NULL))
		return (PAPI_BAD_ARGUMENT);

	return (PAPI_OPERATION_NOT_SUPPORTED);
}

papi_status_t
papiPrinterQuery(papi_service_t handle, const char *name,
		const char **requested_attrs,
		const papi_attribute_t **job_attributes,
		papi_printer_t *printer)
{
	service_t *svc = handle;
	printer_t *p = NULL;

	if ((svc == NULL) || (name == NULL) || (printer == NULL))
		return (PAPI_BAD_ARGUMENT);

	if ((*printer = p = calloc(1, sizeof (*p))) == NULL)
		return (PAPI_TEMPORARY_ERROR);

	return (PAPI_OPERATION_NOT_SUPPORTED);
}

papi_status_t
papiPrinterPause(papi_service_t handle, const char *name, const char *message)
{
	service_t *svc = handle;

	if ((svc == NULL) || (name == NULL))
		return (PAPI_BAD_ARGUMENT);

	if (message == NULL)
		message = gettext("stopped by user");

	return (PAPI_OPERATION_NOT_SUPPORTED);
}

papi_status_t
papiPrinterResume(papi_service_t handle, const char *name)
{
	service_t *svc = handle;

	if ((svc == NULL) || (name == NULL))
		return (PAPI_BAD_ARGUMENT);

	return (PAPI_OPERATION_NOT_SUPPORTED);
}

papi_status_t
papiPrinterModify(papi_service_t handle, const char *name,
		const papi_attribute_t **attributes, papi_printer_t *result)
{
	service_t *svc = handle;

	if ((svc == NULL) || (name == NULL) || (attributes == NULL))
		return (PAPI_BAD_ARGUMENT);

 	return (PAPI_OPERATION_NOT_SUPPORTED);
}


papi_status_t
papiPrinterPurgeJobs(papi_service_t handle, const char *name, papi_job_t **jobs)
{
	service_t *svc = handle;

	if ((svc == NULL) || (name == NULL))
		return (PAPI_BAD_ARGUMENT);

	return (PAPI_OPERATION_NOT_SUPPORTED);
}

papi_status_t
papiPrinterListJobs(papi_service_t handle, const char *name,
		const char **requested_attrs, const int type_mask,
		const int max_num_jobs, papi_job_t **jobs)
{
	service_t *svc = handle;

	if ((svc == NULL) || (name == NULL) || (jobs == NULL))
		return (PAPI_BAD_ARGUMENT);

	return (PAPI_OPERATION_NOT_SUPPORTED);
}

papi_attribute_t **
papiPrinterGetAttributeList(papi_printer_t printer)
{
	printer_t *tmp = printer;

	if (tmp == NULL)
		return (NULL);

	return (tmp->attributes);
}
