/*
 * Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */

/*
 * This file is part of the FSG PAPI Project
 *
 * The FSG PAPI Project is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FSG PAPI Project is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the FSG PAPI Project; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/* $Id: cancel.c,v 1.1.1.1 2002/09/18 19:30:13 jacobs Exp $ */

/*LINTLIBRARY*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <libintl.h>
#include <papi.h>

static void
usage(char *program)
{
	char *name;

	if ((name = strrchr(program, '/')) == NULL)
		name = program;
	else
		name++;

	fprintf(stdout, "Usage: %s [-u user] (printer|request-id ...)\n", name);
	exit (1);
}

static int
is_request(char *name)
{
	char *p = strrchr(name, '-');

	if (p == NULL)
		return (0);

	while (*++p != NULL)
		if (isdigit(*p) == 0)
			return (0);

	return (1);
}

int
main(int ac, char *av[])
{
	int exit_code = 0;
	char *user = NULL;
	char *password = NULL;
	papi_encryption_t encryption = PAPI_ENCRYPT_NEVER;
	int c;

	while ((c = getopt(ac, av, "u:p:")) != EOF)
		switch (c) {
		case 'u':
			user = optarg;
			break;
		case 'p':
			password = optarg;
			break;
		default:
			usage(av[0]);
		}

	for (c = optind; c < ac; c++) {
		papi_status_t status;
		papi_service_t svc = NULL;
		char *value = av[c];

		status = papiServiceCreate(&svc, value, user, password, NULL,
					encryption, NULL);
		if (status != PAPI_OK) {
			char *mesg = papiServiceGetStatusMessage(svc);

			if (mesg == NULL)
				mesg = papiStatusString(status);

			fprintf(stderr, gettext(
				"Failed to contact service for %s: %s\n"),
				value, mesg);
			exit(1);
		}

		if (is_request(value) == 1) { /* is an individual job */
			char *mesg;
			char *printer;
			int32_t id;

			printer = strrchr(value, '-');
			*printer++ = NULL;
			id = atoi(printer);
			printer = value;

			status = papiJobCancel(svc, printer, id);
			if (status != PAPI_OK) {
				mesg = papiServiceGetStatusMessage(svc);
				if (mesg == NULL)
					mesg = papiStatusString(status);

				exit_code = 1;
			} else
				mesg = "cancelled";
			fprintf(stderr, "%s-%d: %s\n", printer, id, mesg);
		} else { /* is a printer */
			papi_job_t *jobs = NULL;

			status = papiPrinterPurgeJobs(svc, value, &jobs);
			if (status != PAPI_OK) {
				char *mesg = papiServiceGetStatusMessage(svc);

				if (mesg == NULL)
					mesg = papiStatusString(status);

				fprintf(stderr, gettext("PurgeJobs %s: %s\n"),
					value, mesg);
				exit_code = 1;
			} else { /* cycle through results */
				fprintf(stderr, gettext("PurgeJobs %s: %s\n"),
					value, "cancelled");
			}
			papiJobListFree(jobs);
		}
	
		papiServiceDestroy(svc);
	}

	exit(exit_code);
}
