/*
 * Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */

/*
 * This file is part of the FSG PAPI Project
 *
 * The FSG PAPI Project is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FSG PAPI Project is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the FSG PAPI Project; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/* $Id: lp.c,v 1.1.1.1 2002/09/18 19:30:13 jacobs Exp $ */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <libintl.h>
#include <papi.h>

static void
usage(char *program)
{
	char *name;

	if ((name = strrchr(program, '/')) == NULL)
		name = program;
	else
		name++;

	fprintf(stdout, "Usage: %s [-c] [-m] [-p] [-s] [-w] [-d destination]  [-f form-name] [-H special-handling] [-n number] [-o option] [-P page-list] [-q priority-level]  [-S character-set  |  print-wheel]   [-t title] [ -T content-type [-r]] [-y mode-list] [file...]\n", name);
	exit (1);
}

int
main(int ac, char *av[])
{
	papi_status_t status;
	papi_service_t svc = NULL;
	papi_attribute_t **list = NULL;
	papi_job_t job = NULL;
	int exit_code = 0;
	char *printer = NULL;
	papi_encryption_t encryption = PAPI_ENCRYPT_NEVER;
	int copy = 0;
	int silent = 0;
	int c;

	while ((c = getopt(ac, av, "H:P:S:T:d:f:i:o:q:t:y:cmwn:prs")) != EOF)
		switch (c) {
		case 'd':
			printer = optarg;
			break;
		case 'n':
			papiAttributeListAddInteger(&list, PAPI_ATTR_EXCL,
					"copies", atoi(optarg));
			break;
		case 'f':
			papiAttributeListAddString(&list, PAPI_ATTR_EXCL,
					"media", optarg);
			break;
		case 't':
			papiAttributeListAddString(&list, PAPI_ATTR_EXCL,
					"job-name", optarg);
			break;
		case 'o':
			if (strstr(optarg, "nobanner") == 0)
				papiAttributeListAddString(&list, PAPI_ATTR_EXCL,
					"job-sheets", "none");
			papiAttributeListAddString(&list, PAPI_ATTR_APPEND,
					"lp-options", optarg);
			break;
		case 'y':
			papiAttributeListAddString(&list, PAPI_ATTR_APPEND,
					"lp-modes", optarg);
			break;
		case 'w':
		case 'm':
			papiAttributeListAddBoolean(&list, PAPI_ATTR_EXCL,
				"rfc-1179-mail", 1);
			break;
		case 'c':
			copy = 1;
			break;
		case 's':	/* suppress message */
			copy = 1;
			break;
		default:
			usage(av[0]);
		}

	if ((printer == NULL) &&
	    ((printer = getenv("PRINTER")) == NULL) &&
	    ((printer = getenv("LPDEST")) == NULL))
		printer = "lp";

	papiAttributeListAddInteger(&list, PAPI_ATTR_EXCL, "copies", 1);
	papiAttributeListAddString(&list, PAPI_ATTR_EXCL,
				"document-format", "application/octet-stream");
	papiAttributeListAddString(&list, PAPI_ATTR_EXCL,
				"job-sheets", "standard");
			

	status = papiServiceCreate(&svc, printer, NULL, NULL, NULL,
					encryption, NULL);
	if (status != PAPI_OK) {
		char *mesg = papiServiceGetStatusMessage(svc);

		if (mesg == NULL)
			mesg = papiStatusString(status);

		fprintf(stderr, gettext(
			"Failed to contact service for %s: %s\n"), printer,
			mesg);
		exit(1);
	}

	status = papiJobSubmit(svc, printer, (const papi_attribute_t **)list,
				NULL, (const char **)&av[optind], &job);

	if (status != PAPI_OK) {
		char *mesg = papiServiceGetStatusMessage(svc);
		if (mesg == NULL) {
			mesg = papiStatusString(status);
			exit_code = 1;
		} else
			mesg = "failed";
		fprintf(stderr, "%s: %s\n", printer, mesg);
	}

	if ((silent == 0) &&
	    ((list = papiJobGetAttributeList(job)) != NULL)) {
		char *tmp = "unknown";

		papiAttributeListGetString(list, NULL, "lpsched-id", &tmp);
		printf("request id is %s (%d file(s))\n", tmp, ac - optind);
	}	

	papiServiceDestroy(svc);

	exit(exit_code);
}
